use std::{time::Duration, net::{SocketAddr, IpAddr, Ipv4Addr}};

use once_cell::sync::OnceCell;
use uuid::Uuid;

mod protocol;
mod server;
mod plugin;
mod ser;
mod varint;
mod client;
mod command;

pub const QC_VERSION: &str = env!("CARGO_PKG_VERSION");
pub static HTTP_CLIENT: OnceCell<reqwest::Client> = OnceCell::new();
pub static CONFIG: OnceCell<ServerConfig> = OnceCell::new();

pub type JsonValue = serde_json::Value;

#[derive(Clone, Debug)]
pub struct Player {
	name: String,
	uuid: Uuid,
}

#[derive(Clone, Debug)]
pub struct ServerConfig {
	address: SocketAddr,
	max_players: u32,
}

#[tokio::main]
async fn main() {

    let port = std::env::var("QC_PORT")
        .unwrap_or_else(|_| "25565".to_owned())
        .parse()
        .unwrap_or(25565_u16);

    let ip = std::env::var("QC_ADDR")
        .unwrap_or_else(|_| "0.0.0.0".to_owned())
        .parse()
        .unwrap_or(IpAddr::V4(Ipv4Addr::UNSPECIFIED));

    let address = SocketAddr::new(ip, port);

	let max_players: u32 = std::env::var("QC_MAX_PLAYERS")
		.map(|s| s.parse().unwrap())
		.unwrap_or(20);

	CONFIG.set(ServerConfig {
		address,
		max_players
	}).unwrap();

	HTTP_CLIENT.set(reqwest::ClientBuilder::new()
		.timeout(Duration::from_secs(5))
		.build().unwrap()
	).unwrap();

	server::run_server().await.unwrap()
}
